Overview — pycollect 0.1.0 documentation

### Navigation

- ☰
- pycollect-0.1.0 »

Fork me on GitHub

# Overview

docs |
tests |
package |

Utility library for collecting valid Python files recursively.

- Free software: MIT license

## Installation

    pip install pycollect

## Basic Usage

    collector = PythonFileCollector()
    python_files = collector.collect()

## Documentation

Complete docs: https://allrod5.github.io/pycollect/

### See also

- CONTRIBUTING

- CHANGELOG

- AUTHORS

### Navigation

- index
- modules |
- next |
- previous |